@@ -3,9 +3,9 @@
 ## author: Brice Ozenne
 ## created: okt 12 2017 (13:16) 
 ## Version: 
-## last-updated: maj 16 2018 (14:33) 
+## last-updated: mar 18 2020 (13:34) 
 ##           By: Brice Ozenne
-##     Update #: 471
+##     Update #: 483
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -43,7 +43,7 @@
 #' formula.lvm <- as.formula(paste0("Y~",paste0(X.name,collapse="+")))
 #'
 #' m <- lvm(formula.lvm)
-#' distribution(m,~Id) <- sequence.lvm(0)
+#' distribution(m,~Id) <- Sequence.lvm(0)
 #' set.seed(10)
 #' d <- sim(m,n)
 #'
@@ -74,8 +74,7 @@
 iid2.lm <- function(object,
                     param = NULL, data = NULL, bias.correct = TRUE, ...){
 
-    sCorrect(object, param = param, data = data,
-             score = TRUE, df = FALSE) <- bias.correct
+    sCorrect(object, param = param, data = data, df = FALSE) <- bias.correct
 
     iid.tempo <- iid2(object, ...)
 
@@ -99,8 +98,7 @@ iid2.lm <- function(object,
 iid2.gls <- function(object, cluster = NULL,
                      param = NULL, data = NULL, bias.correct = TRUE, ...){
 
-    sCorrect(object, cluster = cluster, param = param, data = data,
-             score = TRUE, df = FALSE) <- bias.correct
+    sCorrect(object, cluster = cluster, param = param, data = data, df = FALSE) <- bias.correct
 
     if(!is.null(cluster)){
         cluster <- object$sCorrect$args$cluster
@@ -131,7 +129,6 @@ iid2.lm2 <- function(object, cluster = NULL,
     if(!is.null(param) || !is.null(data)){
         args <- object$sCorrect$args
         args$df <- FALSE
-        args$score <- TRUE
         object$sCorrect <- do.call(sCorrect,
                                    args = c(list(object, param = param, data = data),
                                             args))
@@ -165,20 +162,21 @@ iid2.lm2 <- function(object, cluster = NULL,
 
 }
 
-## * iid2.gls
+## * iid2.gls2
 #' @rdname iid2
 #' @export
 iid2.gls2 <- iid2.lm2
 
-## * iid2.lme
+## * iid2.lme2
 #' @rdname iid2
 #' @export
 iid2.lme2 <- iid2.lm2
 
-## * iid2.lvmfit
+## * iid2.lvmfit2
 #' @rdname iid2
 #' @export
 iid2.lvmfit2 <- function(object, cluster = NULL, data = NULL, ...){
+
     ## try to find cluster in data
     if(!is.null(object$cluster)){
         if(!is.null(cluster)){
